#!/bin/sh

echo "************************************************"

FLASHFS=/flashfs
FLASH_INSTALL=${FLASHFS}/Install
RAM_DIR=/tmp/ram
INSTALL_DIR=${RAM_DIR}/install
RESULT_MAJ="CFG_UPDATE_RESULT=Ok"
cd ${INSTALL_DIR}

echo "Backup de flashfs dans la ram"
BACKUP_DIR="/tmp/ram/backup"
mkdir -p ${BACKUP_DIR}
chmod 777 ${BACKUP_DIR}
cp -R ${FLASHFS}/* ${BACKUP_DIR}

#Demonter flashfs
#echo "Demonter flashfs"
#umount ${FLASHFS}

#Effacer flashfs
#echo "Effacer les fichiers de flashfs"
rm -rf ${FLASHFS}/test
rm -rf ${FLASHFS}/Install
rm -rf ${FLASHFS}/config
rm -rf ${FLASHFS}/defaut_config
rm -rf ${FLASHFS}/saveconfig
rm -rf ${FLASHFS}/log

#Remonter flashfs
#echo "Remonter flashfs"
#FLASHFS=/tmp/flashfs
#mkdir -p ${FLASHFS}
#chmod 777 ${FLASHFS}
#mount -t jffs2 /dev/mtdblock2 ${FLASHFS} -n

#Creer le repertoire log
echo "Creer le repertoire /flashfs/log"
mkdir -p ${FLASHFS}/log
chmod 777 ${FLASHFS}/log

#Creer le repertoire Install
echo "Creer le repertoire /flashfs/Install"
mkdir -p ${FLASHFS}/Install
chmod 777 ${FLASHFS}/Install

#Copier les nouveaux fichiers dans flashfs
echo "Copier default_config de la RAM dans flashfs"
mkdir -p ${FLASHFS}/defaut_config/
chmod 777 ${FLASHFS}/defaut_config
cp defaut_config/* ${FLASHFS}/defaut_config/
chmod -R 777 ${FLASHFS}/defaut_config/*

#Copie des executables des taches applicatives, des scripts de demarrage et d'arret des taches et du service SNMP
echo "Copier les applications de la RAM dans flashfs"
mkdir -p ${FLASHFS}/test/
chmod 777 ${FLASHFS}/test
cp *.exe *_appli versions.txt snmpd ntpd network_reboot.sh fpga.rbf ${FLASHFS}/test/
chmod -R 777 ${FLASHFS}/test/*

echo "Copier install_config de la RAM dans flashfs"
mkdir -p ${FLASHFS}/saveconfig
chmod 777 ${FLASHFS}/saveconfig
cp install_config.sh ${FLASHFS}/saveconfig/install.sh
chmod -R 777 ${FLASHFS}/saveconfig/*

#Copie des pages web
echo "Copier les web pages de la RAM dans flashfs"
mkdir -p ${FLASHFS}/www
chmod 777 ${FLASHFS}/www
echo "Processing www.tgz.md5 file.."
CHECK_WWW_MD5=`md5sum -c www.tgz.md5 |cut -d' ' -f2`
touch ${FLASHFS}/log/maj.log
chmod 777 ${FLASHFS}/log/maj.log
if [ ${CHECK_WWW_MD5} == "OK" ]
then
	echo "www.tgz.md5 OK"
	gunzip -c www.tgz|tar -x -C ${FLASHFS}/www -
	rm -f www.tgz
	rm -f www.tgz.md5
else
	echo "www.tgz.md5 FAILED" >> ${FLASHFS}/log/maj.log
	cp -R ${BACKUP_DIR}/www ${FLASHFS}
	RESULT_MAJ="CFG_UPDATE_RESULT=Alarm"
fi
chmod -R 777 ${FLASHFS}/www

#Copier la config sauvegard dans flashfs
echo "Copier la config sauvegardee en RAM dans flashfs"
mkdir -p ${FLASHFS}/config
chmod 777 ${FLASHFS}/config
cp ${BACKUP_DIR}/config/* ${FLASHFS}/config/
chmod -R 777 ${FLASHFS}/config

#Copier etc sauvegard en RAM dans flashfs
#echo "Copier etc sauvegarde en RAM dans flashfs"
#mkdir -p ${FLASHFS}/etc
#chmod 777 ${FLASHFS}/etc
#cp -R ${BACKUP_DIR}/etc ${FLASHFS}
#chmod -R 777 ${FLASHFS}/etc

#Copie du script de demarrage des services reseaux et des taches applicatives
#Au boot, lancement de /etc/initab qui appelle /etc/rc qui appelle /etc/scripts
echo "Copier les nouveaux fichiers etc de la RAM vers /etc"
cp scripts httpd.conf snmpd.conf ntpd.conf crontab /etc/
cp clean_ramdisk /etc/cron.hourly/
chmod -R 777 /etc

#Copie du nouveau fichier de communication.cfg
echo "Copier les nouveaux fichiers de conf de la RAM vers flashfs"
cp communication_new.cfg ${FLASHFS}/config/
cp ${FLASHFS}/defaut_config/kalman.cfg ${FLASHFS}/config/
cp debug.cfg ${FLASHFS}/config/
cp debug_new.cfg ${FLASHFS}/config/
cp licences.cfg ${FLASHFS}/config/
cp asservissement*.cfg ${FLASHFS}/config/

cp ${FLASHFS}/defaut_config/nmea_out.cfg ${FLASHFS}/config/

touch ${FLASHFS}/config/TensionOscillateur.cfg
chmod 777 ${FLASHFS}/config/TensionOscillateur.cfg
chmod 777 ${FLASHFS}/config/communication_new.cfg
chmod 777 ${FLASHFS}/config/debug.cfg
chmod 777 ${FLASHFS}/config/debug_new.cfg
chmod 777 ${FLASHFS}/config/licences.cfg
chmod 777 ${FLASHFS}/config/nmea_out.cfg
chmod 777 ${FLASHFS}/config/asservissement*.cfg



echo "EC20S software installed dans flashfs"

echo "Verifier integrite des nouveaux fichiers copies"
echo "Si erreurs, recopier le backup"

cp ${INSTALL_DIR}/*.md5 ${FLASHFS}/test
cd ${FLASHFS}/test

for f in *.md5; do 
	echo "Processing ${f} file..."
	CHECKMD5=`md5sum -c ${f} |cut -d' ' -f2`
	
	if [ ${CHECKMD5} == "OK" ]
	then
		echo "OK"
	else
		FILEEXE=`cat ${f}|cut -d' ' -f3`
		echo "${FILEEXE} FAILED" >> ${FLASHFS}/log/maj.log
		cp ${BACKUP_DIR}/test/* ${FLASHFS}/test/
		RESULT_MAJ="CFG_UPDATE_RESULT=Alarm"
		
		touch ${FLASHFS}/log/update.result
		chmod 777 ${FLASHFS}/log/update.result
		echo ${RESULT_MAJ} > ${FLASHFS}/log/update.result
		
		exit 
	fi
done

cp reboot.exe /etc/
chmod 777 /etc/reboot.exe


#Programmer le FPGA
echo "Programmer le FPGA"
echo "Processing fpga.rbf.md5 file.."
CHECK_FPGA_MD5=`md5sum -c fpga.rbf.md5 |cut -d' ' -f2`
touch ${FLASHFS}/log/maj.log
chmod 777 ${FLASHFS}/log/maj.log
if [ ${CHECK_FPGA_MD5} == "OK" ]
then
	echo "fpga.rbf.md5 OK"
	touch ${FLASHFS}/log/update.result
	chmod 777 ${FLASHFS}/log/update.result
	echo ${RESULT_MAJ} > ${FLASHFS}/log/update.result

	${FLASHFS}/test/epcs.exe ${FLASHFS}/test/fpga.rbf 03.02
else
	echo " fpga.rbf.md5 FAILED" >> ${FLASHFS}/log/maj.log
	RESULT_MAJ="CFG_UPDATE_RESULT=Alarm"
fi

touch ${FLASHFS}/log/update.result
chmod 777 ${FLASHFS}/log/update.result
echo ${RESULT_MAJ} > ${FLASHFS}/log/update.result

echo "************************************************"
